Documentation
¶
Index ¶
- type BuildLister
- type BuildListerExpansion
- type BuildNamespaceLister
- type BuildNamespaceListerExpansion
- type CamelCatalogLister
- type CamelCatalogListerExpansion
- type CamelCatalogNamespaceLister
- type CamelCatalogNamespaceListerExpansion
- type IntegrationKitLister
- type IntegrationKitListerExpansion
- type IntegrationKitNamespaceLister
- type IntegrationKitNamespaceListerExpansion
- type IntegrationLister
- type IntegrationListerExpansion
- type IntegrationNamespaceLister
- type IntegrationNamespaceListerExpansion
- type IntegrationPlatformLister
- type IntegrationPlatformListerExpansion
- type IntegrationPlatformNamespaceLister
- type IntegrationPlatformNamespaceListerExpansion
- type KameletLister
- type KameletListerExpansion
- type KameletNamespaceLister
- type KameletNamespaceListerExpansion
- type PipeLister
- type PipeListerExpansion
- type PipeNamespaceLister
- type PipeNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildLister ¶
type BuildLister interface {
// List lists all Builds in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Build, err error)
// Builds returns an object that can list and get Builds.
Builds(namespace string) BuildNamespaceLister
BuildListerExpansion
}
BuildLister helps list Builds. All objects returned here must be treated as read-only.
func NewBuildLister ¶
func NewBuildLister(indexer cache.Indexer) BuildLister
NewBuildLister returns a new BuildLister.
type BuildListerExpansion ¶
type BuildListerExpansion interface{}
BuildListerExpansion allows custom methods to be added to BuildLister.
type BuildNamespaceLister ¶
type BuildNamespaceLister interface {
// List lists all Builds in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Build, err error)
// Get retrieves the Build from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.Build, error)
BuildNamespaceListerExpansion
}
BuildNamespaceLister helps list and get Builds. All objects returned here must be treated as read-only.
type BuildNamespaceListerExpansion ¶
type BuildNamespaceListerExpansion interface{}
BuildNamespaceListerExpansion allows custom methods to be added to BuildNamespaceLister.
type CamelCatalogLister ¶
type CamelCatalogLister interface {
// List lists all CamelCatalogs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.CamelCatalog, err error)
// CamelCatalogs returns an object that can list and get CamelCatalogs.
CamelCatalogs(namespace string) CamelCatalogNamespaceLister
CamelCatalogListerExpansion
}
CamelCatalogLister helps list CamelCatalogs. All objects returned here must be treated as read-only.
func NewCamelCatalogLister ¶
func NewCamelCatalogLister(indexer cache.Indexer) CamelCatalogLister
NewCamelCatalogLister returns a new CamelCatalogLister.
type CamelCatalogListerExpansion ¶
type CamelCatalogListerExpansion interface{}
CamelCatalogListerExpansion allows custom methods to be added to CamelCatalogLister.
type CamelCatalogNamespaceLister ¶
type CamelCatalogNamespaceLister interface {
// List lists all CamelCatalogs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.CamelCatalog, err error)
// Get retrieves the CamelCatalog from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.CamelCatalog, error)
CamelCatalogNamespaceListerExpansion
}
CamelCatalogNamespaceLister helps list and get CamelCatalogs. All objects returned here must be treated as read-only.
type CamelCatalogNamespaceListerExpansion ¶
type CamelCatalogNamespaceListerExpansion interface{}
CamelCatalogNamespaceListerExpansion allows custom methods to be added to CamelCatalogNamespaceLister.
type IntegrationKitLister ¶
type IntegrationKitLister interface {
// List lists all IntegrationKits in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.IntegrationKit, err error)
// IntegrationKits returns an object that can list and get IntegrationKits.
IntegrationKits(namespace string) IntegrationKitNamespaceLister
IntegrationKitListerExpansion
}
IntegrationKitLister helps list IntegrationKits. All objects returned here must be treated as read-only.
func NewIntegrationKitLister ¶
func NewIntegrationKitLister(indexer cache.Indexer) IntegrationKitLister
NewIntegrationKitLister returns a new IntegrationKitLister.
type IntegrationKitListerExpansion ¶
type IntegrationKitListerExpansion interface{}
IntegrationKitListerExpansion allows custom methods to be added to IntegrationKitLister.
type IntegrationKitNamespaceLister ¶
type IntegrationKitNamespaceLister interface {
// List lists all IntegrationKits in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.IntegrationKit, err error)
// Get retrieves the IntegrationKit from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.IntegrationKit, error)
IntegrationKitNamespaceListerExpansion
}
IntegrationKitNamespaceLister helps list and get IntegrationKits. All objects returned here must be treated as read-only.
type IntegrationKitNamespaceListerExpansion ¶
type IntegrationKitNamespaceListerExpansion interface{}
IntegrationKitNamespaceListerExpansion allows custom methods to be added to IntegrationKitNamespaceLister.
type IntegrationLister ¶
type IntegrationLister interface {
// List lists all Integrations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Integration, err error)
// Integrations returns an object that can list and get Integrations.
Integrations(namespace string) IntegrationNamespaceLister
IntegrationListerExpansion
}
IntegrationLister helps list Integrations. All objects returned here must be treated as read-only.
func NewIntegrationLister ¶
func NewIntegrationLister(indexer cache.Indexer) IntegrationLister
NewIntegrationLister returns a new IntegrationLister.
type IntegrationListerExpansion ¶
type IntegrationListerExpansion interface{}
IntegrationListerExpansion allows custom methods to be added to IntegrationLister.
type IntegrationNamespaceLister ¶
type IntegrationNamespaceLister interface {
// List lists all Integrations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Integration, err error)
// Get retrieves the Integration from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.Integration, error)
IntegrationNamespaceListerExpansion
}
IntegrationNamespaceLister helps list and get Integrations. All objects returned here must be treated as read-only.
type IntegrationNamespaceListerExpansion ¶
type IntegrationNamespaceListerExpansion interface{}
IntegrationNamespaceListerExpansion allows custom methods to be added to IntegrationNamespaceLister.
type IntegrationPlatformLister ¶
type IntegrationPlatformLister interface {
// List lists all IntegrationPlatforms in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.IntegrationPlatform, err error)
// IntegrationPlatforms returns an object that can list and get IntegrationPlatforms.
IntegrationPlatforms(namespace string) IntegrationPlatformNamespaceLister
IntegrationPlatformListerExpansion
}
IntegrationPlatformLister helps list IntegrationPlatforms. All objects returned here must be treated as read-only.
func NewIntegrationPlatformLister ¶
func NewIntegrationPlatformLister(indexer cache.Indexer) IntegrationPlatformLister
NewIntegrationPlatformLister returns a new IntegrationPlatformLister.
type IntegrationPlatformListerExpansion ¶
type IntegrationPlatformListerExpansion interface{}
IntegrationPlatformListerExpansion allows custom methods to be added to IntegrationPlatformLister.
type IntegrationPlatformNamespaceLister ¶
type IntegrationPlatformNamespaceLister interface {
// List lists all IntegrationPlatforms in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.IntegrationPlatform, err error)
// Get retrieves the IntegrationPlatform from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.IntegrationPlatform, error)
IntegrationPlatformNamespaceListerExpansion
}
IntegrationPlatformNamespaceLister helps list and get IntegrationPlatforms. All objects returned here must be treated as read-only.
type IntegrationPlatformNamespaceListerExpansion ¶
type IntegrationPlatformNamespaceListerExpansion interface{}
IntegrationPlatformNamespaceListerExpansion allows custom methods to be added to IntegrationPlatformNamespaceLister.
type KameletLister ¶
type KameletLister interface {
// List lists all Kamelets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Kamelet, err error)
// Kamelets returns an object that can list and get Kamelets.
Kamelets(namespace string) KameletNamespaceLister
KameletListerExpansion
}
KameletLister helps list Kamelets. All objects returned here must be treated as read-only.
func NewKameletLister ¶
func NewKameletLister(indexer cache.Indexer) KameletLister
NewKameletLister returns a new KameletLister.
type KameletListerExpansion ¶
type KameletListerExpansion interface{}
KameletListerExpansion allows custom methods to be added to KameletLister.
type KameletNamespaceLister ¶
type KameletNamespaceLister interface {
// List lists all Kamelets in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Kamelet, err error)
// Get retrieves the Kamelet from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.Kamelet, error)
KameletNamespaceListerExpansion
}
KameletNamespaceLister helps list and get Kamelets. All objects returned here must be treated as read-only.
type KameletNamespaceListerExpansion ¶
type KameletNamespaceListerExpansion interface{}
KameletNamespaceListerExpansion allows custom methods to be added to KameletNamespaceLister.
type PipeLister ¶
type PipeLister interface {
// List lists all Pipes in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Pipe, err error)
// Pipes returns an object that can list and get Pipes.
Pipes(namespace string) PipeNamespaceLister
PipeListerExpansion
}
PipeLister helps list Pipes. All objects returned here must be treated as read-only.
func NewPipeLister ¶
func NewPipeLister(indexer cache.Indexer) PipeLister
NewPipeLister returns a new PipeLister.
type PipeListerExpansion ¶
type PipeListerExpansion interface{}
PipeListerExpansion allows custom methods to be added to PipeLister.
type PipeNamespaceLister ¶
type PipeNamespaceLister interface {
// List lists all Pipes in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Pipe, err error)
// Get retrieves the Pipe from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.Pipe, error)
PipeNamespaceListerExpansion
}
PipeNamespaceLister helps list and get Pipes. All objects returned here must be treated as read-only.
type PipeNamespaceListerExpansion ¶
type PipeNamespaceListerExpansion interface{}
PipeNamespaceListerExpansion allows custom methods to be added to PipeNamespaceLister.